# tnsgrt

This package contains classes and functions that facilitate the design and analysis of tensegrity structures.
It started as a matlab toolbox many years ago written by Mauricio de Oliveira and Joseph Cessna, which is now been
ported to Python.

It relies heavily on [numpy](https://numpy.org>), [scipy](https://scipy.org), [pandas](https://pandas.org), and
[cvxpy](https://cvxpy.org) for computations.

Visualization is supported via [matplotlib](https://matplotlib.org) and
[vispy](https://vispy.org).

## Installation

Install with pip by typing:

    pip install tnsgrt

## Documentation

See on [read the docs](https://tnsgrt.readthedocs.io).
